summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/factories/stdwidgetfactory.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/factories/stdwidgetfactory.cpp')
-rw-r--r--kexi/formeditor/factories/stdwidgetfactory.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kexi/formeditor/factories/stdwidgetfactory.cpp b/kexi/formeditor/factories/stdwidgetfactory.cpp
index 24827e13..afc37086 100644
--- a/kexi/formeditor/factories/stdwidgetfactory.cpp
+++ b/kexi/formeditor/factories/stdwidgetfactory.cpp
@@ -431,13 +431,13 @@ StdWidgetFactory::createWidget(const TQCString &c, TQWidget *p, const char *n,
w = new KProgress(p, n);
else if(c == "KDateWidget")
- w = new KDateWidget(TQDate::tqcurrentDate(), p, n);
+ w = new KDateWidget(TQDate::currentDate(), p, n);
else if(c == "KTimeWidget")
w = new KTimeWidget(TQTime::currentTime(), p, n);
else if(c == "KDateTimeWidget")
- w = new KDateTimeWidget(TQDateTime::tqcurrentDateTime(), p, n);
+ w = new KDateTimeWidget(TQDateTime::currentDateTime(), p, n);
else if(c == "Line")
w = new Line(options & WidgetFactory::VerticalOrientation ? Qt::Vertical : Qt::Horizontal, p, n);
@@ -605,13 +605,13 @@ StdWidgetFactory::changeText(const TQString &text)
else
changeProperty("text", text, m_container->form());
/* By-hand method not needed as tqsizeHint() can do that for us
TQFontMetrics fm = w->fontMetrics();
TQSize s(fm.width( text ), fm.height());
int width;
if(n == TQLABEL_OBJECT_NAME_STRING) // labels are resized to fit the text
{
- w->resize(w->tqsizeHint());
+ w->resize(w->sizeHint());
WidgetFactory::m_editor->resize(w->size());
return;
}
@@ -624,7 +624,7 @@ StdWidgetFactory::changeText(const TQString &text)
width = w->style().sizeFromContents( TQStyle::CT_RadioButton, w, s).width();
else
return;
- int width = w->tqsizeHint().width();*/
+ int width = w->sizeHint().width();*/
#if 0 //not needed here, size hint is used on creation in InsertWidgetCommand::execute()
if(w->width() < width)
@@ -956,7 +956,7 @@ StdWidgetFactory::editText()
}
if(classname == TQLABEL_OBJECT_NAME_STRING)
- widget()->resize(widget()->tqsizeHint());
+ widget()->resize(widget()->sizeHint());
}
void
@@ -605,13 +605,13 @@ StdWidgetFactory::changeText(const TQString &text)
else
changeProperty("text", text, m_container->form());
- /* By-hand method not needed as tqsizeHint() can do that for us
+ /* By-hand method not needed as sizeHint() can do that for us
TQFontMetrics fm = w->fontMetrics();
TQSize s(fm.width( text ), fm.height());